clear all

% Program that calculates the time evolution of the 
% density matrix for an Anderson impurity model

% parameters of the Impurity


e_d = 2; % On-site energy 
U = 3;   % Interaction

%general parameters
finesse = 200;
Vb_vec = linspace(-10,10,finesse);
Vg_vec = linspace(-5,5,finesse);
mu_0 = e_d + U/2;
ratio = 1;
c = 1/(1+ratio); 




for i= 1:length(Vb_vec)
    Vb = Vb_vec(i);
    for j = 1:length(Vg_vec)
        Vg = Vg_vec(j);
        
% Bath parameters
T = 0.1*[1 1];        % Temperatures
mu = mu_0 + [+c*Vb -(1-c)*Vb]; % Chemical potentials

% Parameters of the coupling
Gamma = [0.01 0.01]; %bath-impurity tunnelling rates

% Energy, particle number and Free energy of 
% the many body eigenstates 
N = [0 1 1 2];

En = [0, e_d, e_d, 2*e_d+U] + N*Vg;

for k =1:2
% Usefull f+ and f- components of the Liouvillean
fp = fermi(e_d+Vg-mu(k),T(k));
fm = 1-fp;
fUp = fermi(e_d+Vg+U-mu(k),T(k));
fUm = 1-fUp;


% the Liouvilleans
L(:,:,k) = Gamma(k)*[-2*fp,fm,fm,0;...
           fp,-fm-fUp,0,fUm;...
           fp,0,-fm-fUp,fUm;...
           0,fUp,fUp,-2*fUm];
end

L_tot = L(:,:,1) + L(:,:,2);

rho_Stat = null(L_tot);
rho_Stat = rho_Stat/sum(rho_Stat);

P_0(i,j) = rho_Stat(1); 
P1s(i,j) = rho_Stat(2);
P_2(i,j) = rho_Stat(4);

I_L(i,j) = N*L(:,:,1)*rho_Stat; 
I_R(i,j) = N*L(:,:,2)*rho_Stat;
    end
i
end
plot(Vg_vec,I_L)
% Calculation of the differential conductance
dI_L = diff(I_L,1,1)./repmat(diff(Vb_vec)',1,length(Vg_vec));




% Graphical representation
figure(1)

subplot(1,2,1)
surf(Vg_vec,Vb_vec,I_L)
view([0 90])
shading flat
title('Current','Fontsize',18)
xlabel('V_g','Fontsize',18)
ylabel('V_b','Fontsize',18)

subplot(1,2,2)
surf(Vg_vec,Vb_vec(1:end-1),dI_L)
view([0 90])
shading flat
axis tight
title('Differential conductance','Fontsize',18)
xlabel('V_g','Fontsize',18)
ylabel('V_b','Fontsize',18)

figure(2)

subplot(1,3,1)
surf(Vg_vec,Vb_vec,P_0)
view([0 90])
caxis([0 1])
shading flat
title('P_0','Fontsize',18)
xlabel('V_g','Fontsize',18)
ylabel('V_b','Fontsize',18)

subplot(1,3,2)
surf(Vg_vec,Vb_vec,P1s)
view([0 90])
caxis([0 1])
shading flat
axis tight
title('P_{1\sigma}','Fontsize',18)
xlabel('V_g','Fontsize',18)
ylabel('V_b','Fontsize',18)

subplot(1,3,3)
surf(Vg_vec,Vb_vec,P_2)
view([0 90])
caxis([0 1])
shading flat
title('P_2','Fontsize',18)
xlabel('V_g','Fontsize',18)
ylabel('V_b','Fontsize',18)







